{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#cgp-seqval-qc_pairs.cwl",
            "label": "CGP sequence validator",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-seqval:0.1.1"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Fastq files to verify, can be gzipped.",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1,
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#cgp-seqval-qc_pairs.cwl/cgp-seqval/fastqs_in"
                },
                {
                    "type": "string",
                    "doc": "Not to be overridden by users: Output as interleaved FASTQ (ignored for interleaved input)",
                    "default": "interleaved.fq.gz",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 3,
                        "separate": true
                    },
                    "id": "#cgp-seqval-qc_pairs.cwl/cgp-seqval/output_fq"
                },
                {
                    "type": "int",
                    "doc": "Assess phred quality scale using N pairs (0=all, slow)",
                    "default": 100000,
                    "inputBinding": {
                        "prefix": "-q",
                        "position": 2,
                        "separate": true
                    },
                    "id": "#cgp-seqval-qc_pairs.cwl/cgp-seqval/qc_pairs"
                }
            ],
            "baseCommand": [
                "cgpSeqInputVal",
                "seq-valid",
                "-r",
                "report.json"
            ],
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-seqval/status)\nA Docker container for validating interleaved fastq files.\n\nSee the dockstore-cgp-seqval [README](https://github.com/cancerit/dockstore-cgp-seqval/blob/develop/README.md)\nfor full details of how to use.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/dockstore-cgp-seqval",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/identifier": "https://orcid.org/0000-0002-5634-1539",
                    "http://schema.org/email": "mailto:keiranmraine@gmail.com",
                    "http://schema.org/name": "Keiran Raine"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "keiranmraine@gmail.com",
                "foaf:name": "Keiran Raine",
                "foaf:mbox": "keiranmraine@gmail.com"
            },
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "interleaved.fq.gz"
                    },
                    "id": "#cgp-seqval-qc_pairs.cwl/cgp-seqval/ifastq_out"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3464",
                    "outputBinding": {
                        "glob": "report.json"
                    },
                    "id": "#cgp-seqval-qc_pairs.cwl/cgp-seqval/report_json"
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "A CGP workflow to move and validate an interleave fastq",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "A gzipped interleaved fastq file.",
                    "id": "#main/fastq_in"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputSource": "#main/rename/outfile",
                    "id": "#main/interleaved_fastq_out"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3464",
                    "outputSource": "#main/validate/report_json",
                    "id": "#main/report"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/fastq_in",
                            "valueFrom": "$(self.basename)",
                            "id": "#main/rename/newname"
                        },
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/rename/srcfile"
                        }
                    ],
                    "out": [
                        "#main/rename/outfile"
                    ],
                    "run": "#rename.cwl",
                    "id": "#main/rename"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/rename/outfile"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/validate/fastqs_in"
                        }
                    ],
                    "out": [
                        "#main/validate/report_json"
                    ],
                    "run": "#cgp-seqval-qc_pairs.cwl",
                    "id": "#main/validate"
                }
            ],
            "doc": "A workflow to copy the input interleaved fastq file to a new place and validate the file format and base quality score range. See the [workflow-seq-import](https://github.com/cancerit/workflow-seq-import) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/workflow-seq-import",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yyaobo@gmail.com",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yyaobo@gmail.com"
            }
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "true",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "$(inputs.newname)",
                            "entry": "$(inputs.srcfile)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#rename.cwl/newname"
                },
                {
                    "type": "File",
                    "id": "#rename.cwl/srcfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.newname)"
                    },
                    "id": "#rename.cwl/outfile"
                }
            ],
            "id": "#rename.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.18.owl"
    ],
    "$namespaces": {
        "s": "http://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
